++++++++++++++++++++++++++
Python C API compatibility
++++++++++++++++++++++++++

The ``pythoncapi-compat`` project can be used to write a C or C++ extension
supporting a wide range of Python versions with a single code base.  It is made
of the ``pythoncapi_compat.h`` header file and the ``upgrade_pythoncapi.py``
script.

* Homepage: `GitHub pythoncapi-compat project
  <https://github.com/python/pythoncapi-compat>`_.
* `Documentation
  <https://pythoncapi-compat.readthedocs.io/en/latest/>`_

Documentation:

.. toctree::
   :maxdepth: 2

   upgrade
   api
   users
   tests
   changelog
   links

This project is distributed under the `Zero Clause BSD (0BSD) license
<https://opensource.org/licenses/0BSD>`_ and is covered by the `PSF Code of
Conduct <https://www.python.org/psf/codeofconduct/>`_.
